@@ -38,6 +38,7 @@ OC.L10N.register(
     "Create bookmark" : "Luo kirjanmerkki",
     "Takes a link and adds it to your collection of bookmarks." : "Poimii linkin ja lisää sen kirjanmerkkikokoelmaasi",
     "Bookmarks Backups" : "Kirjanmerkkien varmuuskopiot",
+    "Collect and manage bookmarks, synced with all your devices" : "Kerää ja hallitse kirjanmerkkejä, synkronoituna kaikille laitteillesi",
     "Do you really want to delete this bookmark?" : "Haluatko varmasti poistaa tämän kirjanmerkin?",
     "Link copied to clipboard" : "Linkki kopioitu leikepöydälle",
     "Enter new title" : "Syötä uusi nimi",
@@ -56,6 +57,7 @@ OC.L10N.register(
     "This content is being downloaded for offline use. Please check back later." : "Sisältöä ladataan offline-käyttöä varten. Palaa myöhemmin takaisin.",
     "Bookmarked {time} ago" : "Lisätty kirjanmerkkeihin {time} sitten",
     "Bookmarked on {date}" : "Lisätty kirjanmerkkeihin {date}",
+    "These are your deleted items. Items will be deleted permanently after two months." : "Nämä ovat poistamasi kohteet. Ne poistetaan pysyvästi kahden kuukauden jälkeen.",
     "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Kirjanmerkit internetin tiedostoihin, kuten kuviin ja PDF-tiedostoihin, tallennetaan automaattisesti Nextcloud-tiedostoihisi jotta voit löytää ne vaikka linkki ei enää toimisi.",
     "Searching in the current folder only." : "Etsitään vain nykyisestä kansiosta.",
     "Repeat search in all folders" : "Toista haku kaikkiin kansioihin",
@@ -121,6 +123,7 @@ OC.L10N.register(
     "Importing bookmarks" : "Tuodaan kirjanmerkkejä",
     "Moving selection" : "Siirretään valittua kohdetta",
     "Adding selection to folders" : "Lisätään valinta kansioihin",
+    "Emptying trashbin" : "Tyhjennetään roskakoria",
     "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Siirretään %n kansio ja joitain kirjanmerkkejä","Siirretään %n kansiota ja joitain kirjanmerkkejä"],
     "_Moving %n folder_::_Moving %n folders_" : ["Siirretään %n kansio","Siirretään %n kansiota"],
     "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Siirretään %n kirjanmerkki","Siirretään %n kirjanmerkkiä"],
@@ -171,6 +174,7 @@ OC.L10N.register(
     "Support this project" : "Tue tätä projektia",
     "Created {time} ago" : "Luotu {time} sitten",
     "Created on {date}" : "Luotu {date}",
+    "(Empty title)" : "(Tyhjä otsikko)",
     "Title" : "Otsikko",
     "Link" : "Linkki",
     "Untitled folder" : "Nimetön kansio",
@@ -180,6 +184,7 @@ OC.L10N.register(
     "Notes" : "Muistiinpanot",
     "Notes for this bookmark …" : "Muistiinpanot tähän kirjanmerkkiin liittyen…",
     "Archived file" : "Arkistoitu tiedosto",
+    "Open file" : "Avaa tiedosto",
     "Download file" : "Lataa tiedosto",
     "Open file location" : "Avaa tiedoston sijainti",
     "Link copied" : "Linkki kopioitu",
@@ -222,10 +227,13 @@ OC.L10N.register(
     "Save" : "Tallenna",
     "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "Kirjanmerkkisovelluksen verkkokäyttö on oletuksena pois käytöstä. Avaa ylläpidon asetuksista sovelluksen asetukset ottaaksesi käyttöön esikatseluiden ja suosikkikuvakkeiden haut.",
     "What's new?" : "Mitä uutta?",
+    "Leave a rating on the Nextcloud App Store" : "Jätä arvostelu Nextcloud-sovelluskaupassa",
     "What" : "Mitä",
     "Failed to count unavailable bookmarks" : "Käytöstä poissa olevien kirjanmerkkien laskeminen epäonnistui",
     "Failed to count archived bookmarks" : "Arkistoitujen kirjanmerkkien laskeminen epäonnistui",
+    "Failed to count deleted bookmarks" : "Poistettujen kirjanmerkkien määrän laskeminen epäonnistui",
     "Failed to count duplicated bookmarks" : "Kaksoiskappaleiden laskenta epäonnistui",
+    "Failed to count bookmarks" : "Kirjanmerkkien laskeminen epäonnistui",
     "Failed to load bookmark" : "Kirjanmerkin lataaminen epäonnistui",
     "Failed to find existing bookmark" : "Olemassa olevaa kirjanmerkkiä ei löytynyt",
     "Failed to create bookmark" : "Kirjanmerkin luominen epäonnistui",
@@ -233,6 +241,7 @@ OC.L10N.register(
     "Failed to move bookmark" : "Kirjanmerkin siirtäminen epäonnistui",
     "Failed to copy bookmark" : "Kirjanmerkin kopioiminen epäonnistui",
     "Failed to delete bookmark" : "Kirjanmerkin poistaminen epäonnistui",
+    "Failed to restore bookmark" : "Kirjanmerkin palauttaminen epäonnistui",
     "Import successful" : "Tuonti onnistui",
     "Failed to rename tag" : "Tunnisteen uudelleen nimeäminen epäonnistui",
     "Failed to load tags" : "Tunnisteiden lataaminen epäonnistui",
@@ -241,6 +250,7 @@ OC.L10N.register(
     "Failed to load deleted bookmarks" : "Poistettujen kirjanmerkkien lataaminen epäonnistui",
     "Failed to delete folder" : "Kansion poistaminen epäonnistui",
     "Failed to move folder" : "Kansion siirtäminen epäonnistui",
+    "Failed to restore folder" : "Kansion palauttaminen epäonnistui",
     "Failed to create folder" : "Kansion luominen epäonnistui",
     "Failed to move parts of selection" : "Joidenkin valinnan osien siirtäminen epäonnistui",
     "Failed to delete parts of selection" : "Joidenkin valinnan osien poistaminen epäonnistui",
@@ -248,6 +258,8 @@ OC.L10N.register(
     "Failed to load setting {key}" : "Asetuksen {key} lataaminen epäonnistui",
     "Failed to update share {shareId}" : "Jaon {shareId} päivittäminen epäonnistui",
     "Failed to delete share {shareId}" : "Jaon {shareId} poistaminen epäonnistui",
+    "Failed to create public link for folder {folderId}" : "Kansioon {folderId} johtavan julkisen linkin luominen epäonnistui",
+    "Failed to delete public link for folder {folderId}" : "Kansioon {folderId} johtavan julkisen linkin poistaminen epäonnistui",
     "Create bookmarks for mentioned links" : "Luo kirjanmerkit mainituista linkeistä",
     "No links found in this message" : "Viestistä ei löytynyt linkkejä",
     "Bookmarks feed" : "Kirjanmerkkien syöte"
