@@ -132,6 +132,7 @@ OC.L10N.register(
     "_Moving %n bookmark_::_Moving %n bookmarks_" : ["正在移動%n個書籤"],
     "All bookmarks" : "所有書籤",
     "Recent" : "最新",
+    "Frequently clicked" : "經常點擊",
     "Shared with you" : "與您分享",
     "Files" : "檔案",
     "Duplicates" : "複本",
@@ -196,6 +197,7 @@ OC.L10N.register(
     "Notes" : "註釋",
     "Notes for this bookmark …" : "此書籤的註釋...",
     "Archived file" : "已封存檔案",
+    "Open file" : "開啟檔案",
     "Download file" : "下載檔案",
     "Open file location" : "開啟檔案位置",
     "Link copied" : "連結已複製",
@@ -248,6 +250,7 @@ OC.L10N.register(
     "What" : "甚麼",
     "Failed to count unavailable bookmarks" : "無法點算不可用的書籤",
     "Failed to count archived bookmarks" : "無法點算已封存的書籤",
+    "Failed to count deleted bookmarks" : "無法統計已刪除的書籤數量",
     "Failed to count duplicated bookmarks" : "無法點算書籤複本",
     "Failed to count bookmarks" : "無法計算書籤數量",
     "Failed to load bookmark" : "載入書籤失敗",
